/*-------------------------------------------------------------------
Name......... demo.h
Author....... Marc Adams
Date......... 15/09/03
Description.. Header file for the demo project
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

/****	Defines */

/* Counters updated in 10ms interrupt routine for auto demo */
#define LED_ANIM_TIME			50;		/* *1 ms */
#define LAMP_ANIM_TIME			50;		/* *1 ms */
#define DRAIN_OUTPUT_TIME		300;	/* *1 ms */
#define VFD_ANIM_TIME			1000;	/* *1 ms */
#define SERIAL_ANIM_TIME		1000;	/* *1 ms */

/* LED segments */
#define LED_SEG1		0x01
#define LED_SEG2		0x02
#define LED_SEG3		0x04
#define LED_SEG4		0x08
#define LED_SEG5		0x10
#define LED_SEG6		0x20
#define LED_SEG7		0x40


#define		DIL_DATA_SIZE 8

#define		E2ROM_BUFFER_SIZE 512

/**** Console Menu Enumerations */

/* MAIN MENU COMMANDS */
typedef	enum
{
	LAMPSCMD,
	LEDSCMD,
	INPUTSCMD,
	OUTPUTSCMD,
	REELCMD,
	UARTCMD,
	SOUNDCMD,
	VFD1CMD,
	CSDCMD,
	E2ROMCMD,
} CMD;

/* LAMPS COMMANDS */
typedef enum
{
	STROBECMD,
	ROWCMD,
	ONCMD,
	F1CMD,
	FF1CMD,
	DIMCMD,
	RESTORECMD,
	EXITLPCMD
} LAMPCMD;

/* LEDS COMMANDS */
typedef enum
{
	DIGITCMD,
	SEGMENTCMD,
	DIMLEDCMD,
	RESTORELEDCMD,
	EXITLEDCMD,
} LEDCMD;

/* INPUT COMMANDS */
typedef enum
{
	SYSTEMINPUTCMD,
	PUSHBUTTONCMD,
	METERSENSECMD,
	EXITINPUTSCMD,
} INPUTCMD;

/* REEL COMMANDS */
typedef	enum
{
	INITCMD,
	STEP1CMD,
	STEP2CMD,
	STEP3CMD,
	STEP4CMD,
	SPINCMD,
	SKILLCMD,
	STATUSCMD,
	EXITRLCMD
} RLCMD;

/* SERIAL COMMANDS */
typedef enum
{
	CFUART1CMD,
	FPGAUART0CMD,
	FPGAUART1CMD,
	DUART0CMD,
	DUART1CMD,
	EXITUARTCMD,
} SERIALCMD;

/* AUDIO MENUS */
/* MAIN MENU */
typedef enum
{
	LISTFILESCMD,
	SETVOLCMD,
	PLAYCMD,
	LOOPCMD,
	STOPCMD,
	EXITAUDIOCMD
} AUDIOCMD;

/* VOLUME MENU */
typedef enum
{
	VOLLEFTCMD,
	VOLRIGHTCMD,
	VOLLRCMD,
} VOLCMD;


/* CHANNELS MENU */
typedef enum
{
	LEFT0CMD,
	RIGHT0CMD,
	STEREO0CMD,
	LEFT1CMD,
	RIGHT1CMD,
	STEREO1CMD,
} CHANNELCMD;

/* CSD COMMANDS */
typedef	enum
{
	READRTCCMD,
	READRTCFINECMD,
	WRITERTCCMD,
	READLOGCMD,
	CLEARLOGCMD,
	READPERCENTCMD,
	READSTAKECMD,
	READDIL1CMD,
	READDIL2CMD,
	READREVISION,
	EXITCSDCMD,
} TESTPICCMD;

/* E2ROM COMMANDS */
typedef enum
{
	READE2ROMCMD,
	WRITEE2ROMCMD,
	EXITE2ROMCMD,
} TESTE2ROMCMD;

/* CALENDER */
typedef enum
{
	YEAR,
	MONTH,
	DAY,
	HOURS,
	MINS
} CALENDER;


/* ON SCREEN DISPLAY MENUS */
/* MAIN MENU */
static	const	BYTE*const commands[]=
{
	"MAIN MENU",
	"lamps",
	"leds",
	"inputs",
	"outputs",
	"reels",
	"serial",
	"audio",
	"vfd1",
	"csd",
	"e2rom",
	0
};

/* LAMPS MENU */
static	const	BYTE*const lampcommands[]=
{
	"MULTIPLEXED LAMPS MENU",
	"strobe",
	"row",
	"on",
	"flash",
	"fastflash",
	"dim",
	"restore",
	"exit",
	0
};

#define INVALID_COMMAND		255

/* X LAMPS DISPLAY */
static	const	LAMP	big_lamp_x[]=
{
	LAMP(LC0,LR0),LAMP(LC1,LR0),LAMP(LC0,LR1),
	LAMP(LC1,LR1),LAMP(LC2,LR1),LAMP(LC1,LR2),
	LAMP(LC2,LR2),LAMP(LC3,LR2),LAMP(LC2,LR3),
	LAMP(LC3,LR3),LAMP(LC4,LR3),LAMP(LC3,LR4),
	LAMP(LC4,LR4),LAMP(LC5,LR4),LAMP(LC4,LR5),
	LAMP(LC5,LR5),LAMP(LC6,LR5),LAMP(LC5,LR6),
	LAMP(LC6,LR6),LAMP(LC7,LR6),LAMP(LC6,LR7),
	LAMP(LC7,LR7),
	LAMP(LC0,LR15),LAMP(LC1,LR15),LAMP(LC0,LR14),
	LAMP(LC1,LR14),LAMP(LC2,LR14),LAMP(LC1,LR13),
	LAMP(LC2,LR13),LAMP(LC3,LR13),LAMP(LC2,LR12),
	LAMP(LC3,LR12),LAMP(LC4,LR12),LAMP(LC3,LR11),
	LAMP(LC4,LR11),LAMP(LC5,LR11),LAMP(LC4,LR10),
	LAMP(LC5,LR10),LAMP(LC6,LR10),LAMP(LC5,LR9),
	LAMP(LC6,LR9),LAMP(LC7,LR9),LAMP(LC6,LR8),
	LAMP(LC7,LR8),
	LAMP(LC15,LR0),LAMP(LC14,LR0),LAMP(LC15,LR1),
	LAMP(LC14,LR1),LAMP(LC13,LR1),LAMP(LC14,LR2),
	LAMP(LC13,LR2),LAMP(LC12,LR2),LAMP(LC13,LR3),
	LAMP(LC12,LR3),LAMP(LC11,LR3),LAMP(LC12,LR4),
	LAMP(LC11,LR4),LAMP(LC10,LR4),LAMP(LC11,LR5),
	LAMP(LC10,LR5),LAMP(LC9,LR5),LAMP(LC10,LR6),
	LAMP(LC9,LR6),LAMP(LC8,LR6),LAMP(LC9,LR7),
	LAMP(LC8,LR7),
	LAMP(LC15,LR15),LAMP(LC14,LR15),LAMP(LC15,LR14),
	LAMP(LC14,LR14),LAMP(LC13,LR14),LAMP(LC14,LR13),
	LAMP(LC13,LR13),LAMP(LC12,LR13),LAMP(LC13,LR12),
	LAMP(LC12,LR12),LAMP(LC11,LR12),LAMP(LC12,LR11),
	LAMP(LC11,LR11),LAMP(LC10,LR11),LAMP(LC11,LR10),
	LAMP(LC10,LR10),LAMP(LC9,LR10),LAMP(LC10,LR9),
	LAMP(LC9,LR9),LAMP(LC8,LR9),LAMP(LC9,LR8),
	LAMP(LC8,LR8),
	EOF_LAMPS
};

static	const	LAMP	strobe0lps[]={LAMP(LC0,LR0),LAMP(LC0,LR1),LAMP(LC0,LR2),LAMP(LC0,LR3),LAMP(LC0,LR4),LAMP(LC0,LR5),LAMP(LC0,LR6),LAMP(LC0,LR7),LAMP(LC0,LR8),LAMP(LC0,LR9),LAMP(LC0,LR10),LAMP(LC0,LR11),LAMP(LC0,LR12),LAMP(LC0,LR13),LAMP(LC0,LR14),LAMP(LC0,LR15),EOF_LAMPS};
static	const	LAMP	strobe1lps[]={LAMP(LC1,LR0),LAMP(LC1,LR1),LAMP(LC1,LR2),LAMP(LC1,LR3),LAMP(LC1,LR4),LAMP(LC1,LR5),LAMP(LC1,LR6),LAMP(LC1,LR7),LAMP(LC1,LR8),LAMP(LC1,LR9),LAMP(LC1,LR10),LAMP(LC1,LR11),LAMP(LC1,LR12),LAMP(LC1,LR13),LAMP(LC1,LR14),LAMP(LC1,LR15),EOF_LAMPS};
static	const	LAMP	strobe2lps[]={LAMP(LC2,LR0),LAMP(LC2,LR1),LAMP(LC2,LR2),LAMP(LC2,LR3),LAMP(LC2,LR4),LAMP(LC2,LR5),LAMP(LC2,LR6),LAMP(LC2,LR7),LAMP(LC2,LR8),LAMP(LC2,LR9),LAMP(LC2,LR10),LAMP(LC2,LR11),LAMP(LC2,LR12),LAMP(LC2,LR13),LAMP(LC2,LR14),LAMP(LC2,LR15),EOF_LAMPS};
static	const	LAMP	strobe3lps[]={LAMP(LC3,LR0),LAMP(LC3,LR1),LAMP(LC3,LR2),LAMP(LC3,LR3),LAMP(LC3,LR4),LAMP(LC3,LR5),LAMP(LC3,LR6),LAMP(LC3,LR7),LAMP(LC3,LR8),LAMP(LC3,LR9),LAMP(LC3,LR10),LAMP(LC3,LR11),LAMP(LC3,LR12),LAMP(LC3,LR13),LAMP(LC3,LR14),LAMP(LC3,LR15),EOF_LAMPS};
static	const	LAMP	strobe4lps[]={LAMP(LC4,LR0),LAMP(LC4,LR1),LAMP(LC4,LR2),LAMP(LC4,LR3),LAMP(LC4,LR4),LAMP(LC4,LR5),LAMP(LC4,LR6),LAMP(LC4,LR7),LAMP(LC4,LR8),LAMP(LC4,LR9),LAMP(LC4,LR10),LAMP(LC4,LR11),LAMP(LC4,LR12),LAMP(LC4,LR13),LAMP(LC4,LR14),LAMP(LC4,LR15),EOF_LAMPS};
static	const	LAMP	strobe5lps[]={LAMP(LC5,LR0),LAMP(LC5,LR1),LAMP(LC5,LR2),LAMP(LC5,LR3),LAMP(LC5,LR4),LAMP(LC5,LR5),LAMP(LC5,LR6),LAMP(LC5,LR7),LAMP(LC5,LR8),LAMP(LC5,LR9),LAMP(LC5,LR10),LAMP(LC5,LR11),LAMP(LC5,LR12),LAMP(LC5,LR13),LAMP(LC5,LR14),LAMP(LC5,LR15),EOF_LAMPS};
static	const	LAMP	strobe6lps[]={LAMP(LC6,LR0),LAMP(LC6,LR1),LAMP(LC6,LR2),LAMP(LC6,LR3),LAMP(LC6,LR4),LAMP(LC6,LR5),LAMP(LC6,LR6),LAMP(LC6,LR7),LAMP(LC6,LR8),LAMP(LC6,LR9),LAMP(LC6,LR10),LAMP(LC6,LR11),LAMP(LC6,LR12),LAMP(LC6,LR13),LAMP(LC6,LR14),LAMP(LC6,LR15),EOF_LAMPS};
static	const	LAMP	strobe7lps[]={LAMP(LC7,LR0),LAMP(LC7,LR1),LAMP(LC7,LR2),LAMP(LC7,LR3),LAMP(LC7,LR4),LAMP(LC7,LR5),LAMP(LC7,LR6),LAMP(LC7,LR7),LAMP(LC7,LR8),LAMP(LC7,LR9),LAMP(LC7,LR10),LAMP(LC7,LR11),LAMP(LC7,LR12),LAMP(LC7,LR13),LAMP(LC7,LR14),LAMP(LC7,LR15),EOF_LAMPS};
static	const	LAMP	strobe8lps[]={LAMP(LC8,LR0),LAMP(LC8,LR1),LAMP(LC8,LR2),LAMP(LC8,LR3),LAMP(LC8,LR4),LAMP(LC8,LR5),LAMP(LC8,LR6),LAMP(LC8,LR7),LAMP(LC8,LR8),LAMP(LC8,LR9),LAMP(LC8,LR10),LAMP(LC8,LR11),LAMP(LC8,LR12),LAMP(LC8,LR13),LAMP(LC8,LR14),LAMP(LC8,LR15),EOF_LAMPS};
static	const	LAMP	strobe9lps[]={LAMP(LC9,LR0),LAMP(LC9,LR1),LAMP(LC9,LR2),LAMP(LC9,LR3),LAMP(LC9,LR4),LAMP(LC9,LR5),LAMP(LC9,LR6),LAMP(LC9,LR7),LAMP(LC9,LR8),LAMP(LC9,LR9),LAMP(LC9,LR10),LAMP(LC9,LR11),LAMP(LC9,LR12),LAMP(LC9,LR13),LAMP(LC9,LR14),LAMP(LC9,LR15),EOF_LAMPS};
static	const	LAMP	strobe10lps[]={LAMP(LC10,LR0),LAMP(LC10,LR1),LAMP(LC10,LR2),LAMP(LC10,LR3),LAMP(LC10,LR4),LAMP(LC10,LR5),LAMP(LC10,LR6),LAMP(LC10,LR7),LAMP(LC10,LR8),LAMP(LC10,LR9),LAMP(LC10,LR10),LAMP(LC10,LR11),LAMP(LC10,LR12),LAMP(LC10,LR13),LAMP(LC10,LR14),LAMP(LC10,LR15),EOF_LAMPS};
static	const	LAMP	strobe11lps[]={LAMP(LC11,LR0),LAMP(LC11,LR1),LAMP(LC11,LR2),LAMP(LC11,LR3),LAMP(LC11,LR4),LAMP(LC11,LR5),LAMP(LC11,LR6),LAMP(LC11,LR7),LAMP(LC11,LR8),LAMP(LC11,LR9),LAMP(LC11,LR10),LAMP(LC11,LR11),LAMP(LC11,LR12),LAMP(LC11,LR13),LAMP(LC11,LR14),LAMP(LC11,LR15),EOF_LAMPS};
static	const	LAMP	strobe12lps[]={LAMP(LC12,LR0),LAMP(LC12,LR1),LAMP(LC12,LR2),LAMP(LC12,LR3),LAMP(LC12,LR4),LAMP(LC12,LR5),LAMP(LC12,LR6),LAMP(LC12,LR7),LAMP(LC12,LR8),LAMP(LC12,LR9),LAMP(LC12,LR10),LAMP(LC12,LR11),LAMP(LC12,LR12),LAMP(LC12,LR13),LAMP(LC12,LR14),LAMP(LC12,LR15),EOF_LAMPS};
static	const	LAMP	strobe13lps[]={LAMP(LC13,LR0),LAMP(LC13,LR1),LAMP(LC13,LR2),LAMP(LC13,LR3),LAMP(LC13,LR4),LAMP(LC13,LR5),LAMP(LC13,LR6),LAMP(LC13,LR7),LAMP(LC13,LR8),LAMP(LC13,LR9),LAMP(LC13,LR10),LAMP(LC13,LR11),LAMP(LC13,LR12),LAMP(LC13,LR13),LAMP(LC13,LR14),LAMP(LC13,LR15),EOF_LAMPS};
static	const	LAMP	strobe14lps[]={LAMP(LC14,LR0),LAMP(LC14,LR1),LAMP(LC14,LR2),LAMP(LC14,LR3),LAMP(LC14,LR4),LAMP(LC14,LR5),LAMP(LC14,LR6),LAMP(LC14,LR7),LAMP(LC14,LR8),LAMP(LC14,LR9),LAMP(LC14,LR10),LAMP(LC14,LR11),LAMP(LC14,LR12),LAMP(LC14,LR13),LAMP(LC14,LR14),LAMP(LC14,LR15),EOF_LAMPS};
static	const	LAMP	strobe15lps[]={LAMP(LC15,LR0),LAMP(LC15,LR1),LAMP(LC15,LR2),LAMP(LC15,LR3),LAMP(LC15,LR4),LAMP(LC15,LR5),LAMP(LC15,LR6),LAMP(LC15,LR7),LAMP(LC15,LR8),LAMP(LC15,LR9),LAMP(LC15,LR10),LAMP(LC15,LR11),LAMP(LC15,LR12),LAMP(LC15,LR13),LAMP(LC15,LR14),LAMP(LC15,LR15),EOF_LAMPS};

/* LAMP STROBE LINES */
static	const	LAMP*const	strobelst[]=
{
	strobe0lps,
	strobe1lps,
	strobe2lps,
	strobe3lps,
	strobe4lps,
	strobe5lps,
	strobe6lps,
	strobe7lps,
	strobe8lps,
	strobe9lps,
	strobe10lps,
	strobe11lps,
	strobe12lps,
	strobe13lps,
	strobe14lps,
	strobe15lps,
	0
};

static	const	LAMP	row0lps[]= {LAMP(LC0,LR0),LAMP(LC1,LR0),LAMP(LC2,LR0),LAMP(LC3,LR0),LAMP(LC4,LR0),LAMP(LC5,LR0),LAMP(LC6,LR0),LAMP(LC7,LR0),LAMP(LC8,LR0),LAMP(LC9,LR0),LAMP(LC10,LR0),LAMP(LC11,LR0),LAMP(LC12,LR0),LAMP(LC13,LR0),LAMP(LC14,LR0),LAMP(LC15,LR0),EOF_LAMPS};
static	const	LAMP	row1lps[]= {LAMP(LC0,LR1),LAMP(LC1,LR1),LAMP(LC2,LR1),LAMP(LC3,LR1),LAMP(LC4,LR1),LAMP(LC5,LR1),LAMP(LC6,LR1),LAMP(LC7,LR1),LAMP(LC8,LR1),LAMP(LC9,LR1),LAMP(LC10,LR1),LAMP(LC11,LR1),LAMP(LC12,LR1),LAMP(LC13,LR1),LAMP(LC14,LR1),LAMP(LC15,LR1),EOF_LAMPS};
static	const	LAMP	row2lps[]= {LAMP(LC0,LR2),LAMP(LC1,LR2),LAMP(LC2,LR2),LAMP(LC3,LR2),LAMP(LC4,LR2),LAMP(LC5,LR2),LAMP(LC6,LR2),LAMP(LC7,LR2),LAMP(LC8,LR2),LAMP(LC9,LR2),LAMP(LC10,LR2),LAMP(LC11,LR2),LAMP(LC12,LR2),LAMP(LC13,LR2),LAMP(LC14,LR2),LAMP(LC15,LR2),EOF_LAMPS};
static	const	LAMP	row3lps[]= {LAMP(LC0,LR3),LAMP(LC1,LR3),LAMP(LC2,LR3),LAMP(LC3,LR3),LAMP(LC4,LR3),LAMP(LC5,LR3),LAMP(LC6,LR3),LAMP(LC7,LR3),LAMP(LC8,LR3),LAMP(LC9,LR3),LAMP(LC10,LR3),LAMP(LC11,LR3),LAMP(LC12,LR3),LAMP(LC13,LR3),LAMP(LC14,LR3),LAMP(LC15,LR3),EOF_LAMPS};
static	const	LAMP	row4lps[]= {LAMP(LC0,LR4),LAMP(LC1,LR4),LAMP(LC2,LR4),LAMP(LC3,LR4),LAMP(LC4,LR4),LAMP(LC5,LR4),LAMP(LC6,LR4),LAMP(LC7,LR4),LAMP(LC8,LR4),LAMP(LC9,LR4),LAMP(LC10,LR4),LAMP(LC11,LR4),LAMP(LC12,LR4),LAMP(LC13,LR4),LAMP(LC14,LR4),LAMP(LC15,LR4),EOF_LAMPS};
static	const	LAMP	row5lps[]= {LAMP(LC0,LR5),LAMP(LC1,LR5),LAMP(LC2,LR5),LAMP(LC3,LR5),LAMP(LC4,LR5),LAMP(LC5,LR5),LAMP(LC6,LR5),LAMP(LC7,LR5),LAMP(LC8,LR5),LAMP(LC9,LR5),LAMP(LC10,LR5),LAMP(LC11,LR5),LAMP(LC12,LR5),LAMP(LC13,LR5),LAMP(LC14,LR5),LAMP(LC15,LR5),EOF_LAMPS};
static	const	LAMP	row6lps[]= {LAMP(LC0,LR6),LAMP(LC1,LR6),LAMP(LC2,LR6),LAMP(LC3,LR6),LAMP(LC4,LR6),LAMP(LC5,LR6),LAMP(LC6,LR6),LAMP(LC7,LR6),LAMP(LC8,LR6),LAMP(LC9,LR6),LAMP(LC10,LR6),LAMP(LC11,LR6),LAMP(LC12,LR6),LAMP(LC13,LR6),LAMP(LC14,LR6),LAMP(LC15,LR6),EOF_LAMPS};
static	const	LAMP	row7lps[]= {LAMP(LC0,LR7),LAMP(LC1,LR7),LAMP(LC2,LR7),LAMP(LC3,LR7),LAMP(LC4,LR7),LAMP(LC5,LR7),LAMP(LC6,LR7),LAMP(LC7,LR7),LAMP(LC8,LR7),LAMP(LC9,LR7),LAMP(LC10,LR7),LAMP(LC11,LR7),LAMP(LC12,LR7),LAMP(LC13,LR7),LAMP(LC14,LR7),LAMP(LC15,LR7),EOF_LAMPS};
static	const	LAMP	row8lps[]= {LAMP(LC0,LR8),LAMP(LC1,LR8),LAMP(LC2,LR8),LAMP(LC3,LR8),LAMP(LC4,LR8),LAMP(LC5,LR8),LAMP(LC6,LR8),LAMP(LC7,LR8),LAMP(LC8,LR8),LAMP(LC9,LR8),LAMP(LC10,LR8),LAMP(LC11,LR8),LAMP(LC12,LR8),LAMP(LC13,LR8),LAMP(LC14,LR8),LAMP(LC15,LR8),EOF_LAMPS};
static	const	LAMP	row9lps[]= {LAMP(LC0,LR9),LAMP(LC1,LR9),LAMP(LC2,LR9),LAMP(LC3,LR9),LAMP(LC4,LR9),LAMP(LC5,LR9),LAMP(LC6,LR9),LAMP(LC7,LR9),LAMP(LC8,LR9),LAMP(LC9,LR9),LAMP(LC10,LR9),LAMP(LC11,LR9),LAMP(LC12,LR9),LAMP(LC13,LR9),LAMP(LC14,LR9),LAMP(LC15,LR9),EOF_LAMPS};
static	const	LAMP	row10lps[]={LAMP(LC0,LR10),LAMP(LC1,LR10),LAMP(LC2,LR10),LAMP(LC3,LR10),LAMP(LC4,LR10),LAMP(LC5,LR10),LAMP(LC6,LR10),LAMP(LC7,LR10),LAMP(LC8,LR10),LAMP(LC9,LR10),LAMP(LC10,LR10),LAMP(LC11,LR10),LAMP(LC12,LR10),LAMP(LC13,LR10),LAMP(LC14,LR10),LAMP(LC15,LR10),EOF_LAMPS};
static	const	LAMP	row11lps[]={LAMP(LC0,LR11),LAMP(LC1,LR11),LAMP(LC2,LR11),LAMP(LC3,LR11),LAMP(LC4,LR11),LAMP(LC5,LR11),LAMP(LC6,LR11),LAMP(LC7,LR11),LAMP(LC8,LR11),LAMP(LC9,LR11),LAMP(LC10,LR11),LAMP(LC11,LR11),LAMP(LC12,LR11),LAMP(LC13,LR11),LAMP(LC14,LR11),LAMP(LC15,LR11),EOF_LAMPS};
static	const	LAMP	row12lps[]={LAMP(LC0,LR12),LAMP(LC1,LR12),LAMP(LC2,LR12),LAMP(LC3,LR12),LAMP(LC4,LR12),LAMP(LC5,LR12),LAMP(LC6,LR12),LAMP(LC7,LR12),LAMP(LC8,LR12),LAMP(LC9,LR12),LAMP(LC10,LR12),LAMP(LC11,LR12),LAMP(LC12,LR12),LAMP(LC13,LR12),LAMP(LC14,LR12),LAMP(LC15,LR12),EOF_LAMPS};
static	const	LAMP	row13lps[]={LAMP(LC0,LR13),LAMP(LC1,LR13),LAMP(LC2,LR13),LAMP(LC3,LR13),LAMP(LC4,LR13),LAMP(LC5,LR13),LAMP(LC6,LR13),LAMP(LC7,LR13),LAMP(LC8,LR13),LAMP(LC9,LR13),LAMP(LC10,LR13),LAMP(LC11,LR13),LAMP(LC12,LR13),LAMP(LC13,LR13),LAMP(LC14,LR13),LAMP(LC15,LR13),EOF_LAMPS};
static	const	LAMP	row14lps[]={LAMP(LC0,LR14),LAMP(LC1,LR14),LAMP(LC2,LR14),LAMP(LC3,LR14),LAMP(LC4,LR14),LAMP(LC5,LR14),LAMP(LC6,LR14),LAMP(LC7,LR14),LAMP(LC8,LR14),LAMP(LC9,LR14),LAMP(LC10,LR14),LAMP(LC11,LR14),LAMP(LC12,LR14),LAMP(LC13,LR14),LAMP(LC14,LR14),LAMP(LC15,LR14),EOF_LAMPS};
static	const	LAMP	row15lps[]={LAMP(LC0,LR15),LAMP(LC1,LR15),LAMP(LC2,LR15),LAMP(LC3,LR15),LAMP(LC4,LR15),LAMP(LC5,LR15),LAMP(LC6,LR15),LAMP(LC7,LR15),LAMP(LC8,LR15),LAMP(LC9,LR15),LAMP(LC10,LR15),LAMP(LC11,LR15),LAMP(LC12,LR15),LAMP(LC13,LR15),LAMP(LC14,LR15),LAMP(LC15,LR15),EOF_LAMPS};

/* LAMP STROBE ROWS */
static const	LAMP*const	rowlst[]=
{
	row0lps,
	row1lps,
	row2lps,
	row3lps,
	row4lps,
	row5lps,
	row6lps,
	row7lps,
	row8lps,
	row9lps,
	row10lps,
	row11lps,
	row12lps,
	row13lps,
	row14lps,
	row15lps,
	0
};

static 	const 	LAMP	lamp_sqr1[] = {LAMP(LC7,LR7),LAMP(LC7,LR8),LAMP(LC8,LR7),LAMP(LC8,LR8),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr2[] = {LAMP(LC6,LR6),LAMP(LC6,LR7),LAMP(LC6,LR8),LAMP(LC6,LR9),LAMP(LC7,LR6),LAMP(LC7,LR9),LAMP(LC8,LR6),LAMP(LC8,LR9),LAMP(LC9,LR6),LAMP(LC9,LR7),LAMP(LC9,LR8),LAMP(LC9,LR9),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr3[] = {LAMP(LC5,LR5),LAMP(LC5,LR6),LAMP(LC5,LR7),LAMP(LC5,LR8),LAMP(LC5,LR9),LAMP(LC5,LR10),LAMP(LC6,LR5),LAMP(LC6,LR10),LAMP(LC7,LR5),LAMP(LC7,LR10),LAMP(LC8,LR5),LAMP(LC8,LR10),LAMP(LC9,LR5),LAMP(LC9,LR10),LAMP(LC10,LR5),LAMP(LC10,LR6),LAMP(LC10,LR7),LAMP(LC10,LR8),LAMP(LC10,LR9),LAMP(LC10,LR10),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr4[] = {LAMP(LC4,LR4),LAMP(LC4,LR5),LAMP(LC4,LR6),LAMP(LC4,LR7),LAMP(LC4,LR8),LAMP(LC4,LR9),LAMP(LC4,LR10),LAMP(LC4,LR11),LAMP(LC5,LR4),LAMP(LC5,LR11),LAMP(LC6,LR4),LAMP(LC6,LR11),LAMP(LC7,LR4),LAMP(LC7,LR11),LAMP(LC8,LR4),LAMP(LC8,LR11),LAMP(LC9,LR4),LAMP(LC9,LR11),LAMP(LC10,LR4),LAMP(LC10,LR11),LAMP(LC11,LR4),LAMP(LC11,LR5),LAMP(LC11,LR6),LAMP(LC11,LR7),LAMP(LC11,LR8),LAMP(LC11,LR9),LAMP(LC11,LR10),LAMP(LC11,LR11),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr5[] = {LAMP(LC3,LR3),LAMP(LC3,LR4),LAMP(LC3,LR5),LAMP(LC3,LR6),LAMP(LC3,LR7),LAMP(LC3,LR8),LAMP(LC3,LR9),LAMP(LC3,LR10),LAMP(LC3,LR11),LAMP(LC3,LR12),LAMP(LC4,LR3),LAMP(LC4,LR12),LAMP(LC5,LR3),LAMP(LC5,LR12),LAMP(LC6,LR3),LAMP(LC6,LR12),LAMP(LC7,LR3),LAMP(LC7,LR12),LAMP(LC8,LR3),LAMP(LC8,LR12),LAMP(LC9,LR3),LAMP(LC9,LR12),LAMP(LC10,LR3),LAMP(LC10,LR12),LAMP(LC11,LR3),LAMP(LC11,LR12),LAMP(LC12,LR3),LAMP(LC12,LR4),LAMP(LC12,LR5),LAMP(LC12,LR6),LAMP(LC12,LR7),LAMP(LC12,LR8),LAMP(LC12,LR9),LAMP(LC12,LR10),LAMP(LC12,LR11),LAMP(LC12,LR12),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr6[] = {LAMP(LC2,LR2),LAMP(LC2,LR3),LAMP(LC2,LR4),LAMP(LC2,LR5),LAMP(LC2,LR6),LAMP(LC2,LR7),LAMP(LC2,LR8),LAMP(LC2,LR9),LAMP(LC2,LR10),LAMP(LC2,LR11),LAMP(LC2,LR12),LAMP(LC2,LR13),LAMP(LC3,LR2),LAMP(LC3,LR13),LAMP(LC4,LR2),LAMP(LC4,LR13),LAMP(LC5,LR2),LAMP(LC5,LR13),LAMP(LC6,LR2),LAMP(LC6,LR13),LAMP(LC7,LR2),LAMP(LC7,LR13),LAMP(LC8,LR2),LAMP(LC8,LR13),LAMP(LC9,LR2),LAMP(LC9,LR13),LAMP(LC10,LR2),LAMP(LC10,LR13),LAMP(LC11,LR2),LAMP(LC11,LR13),LAMP(LC12,LR2),LAMP(LC12,LR13),LAMP(LC13,LR2),LAMP(LC13,LR3),LAMP(LC13,LR4),LAMP(LC13,LR5),LAMP(LC13,LR6),LAMP(LC13,LR7),LAMP(LC13,LR8),LAMP(LC13,LR9),LAMP(LC13,LR10),LAMP(LC13,LR11),LAMP(LC13,LR12),LAMP(LC13,LR13),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr7[] = {LAMP(LC1,LR1),LAMP(LC1,LR2),LAMP(LC1,LR3),LAMP(LC1,LR4),LAMP(LC1,LR5),LAMP(LC1,LR6),LAMP(LC1,LR7),LAMP(LC1,LR8),LAMP(LC1,LR9),LAMP(LC1,LR10),LAMP(LC1,LR11),LAMP(LC1,LR12),LAMP(LC1,LR13),LAMP(LC1,LR14),LAMP(LC2,LR1),LAMP(LC2,LR14),LAMP(LC3,LR1),LAMP(LC3,LR14),LAMP(LC4,LR1),LAMP(LC4,LR14),LAMP(LC5,LR1),LAMP(LC5,LR14),LAMP(LC6,LR1),LAMP(LC6,LR14),LAMP(LC7,LR1),LAMP(LC7,LR14),LAMP(LC8,LR1),LAMP(LC8,LR14),LAMP(LC9,LR1),LAMP(LC9,LR14),LAMP(LC10,LR1),LAMP(LC10,LR14),LAMP(LC11,LR1),LAMP(LC11,LR14),LAMP(LC12,LR1),LAMP(LC12,LR14),LAMP(LC13,LR1),LAMP(LC13,LR14),LAMP(LC14,LR1),LAMP(LC14,LR2),LAMP(LC14,LR3),LAMP(LC14,LR4),LAMP(LC14,LR5),LAMP(LC14,LR6),LAMP(LC14,LR7),LAMP(LC14,LR8),LAMP(LC14,LR9),LAMP(LC14,LR10),LAMP(LC14,LR11),LAMP(LC14,LR12),LAMP(LC14,LR13),LAMP(LC14,LR14),EOF_LAMPS};
static 	const 	LAMP	lamp_sqr8[] = {LAMP(LC0,LR0),LAMP(LC0,LR1),LAMP(LC0,LR2),LAMP(LC0,LR3),LAMP(LC0,LR4),LAMP(LC0,LR5),LAMP(LC0,LR6),LAMP(LC0,LR7),LAMP(LC0,LR8),LAMP(LC0,LR9),LAMP(LC0,LR10),LAMP(LC0,LR11),LAMP(LC0,LR12),LAMP(LC0,LR13),LAMP(LC0,LR14),LAMP(LC0,LR15),LAMP(LC1,LR0),LAMP(LC1,LR15),LAMP(LC2,LR0),LAMP(LC2,LR15),LAMP(LC3,LR0),LAMP(LC3,LR15),LAMP(LC4,LR0),LAMP(LC4,LR15),LAMP(LC5,LR0),LAMP(LC5,LR15),LAMP(LC6,LR0),LAMP(LC6,LR15),LAMP(LC7,LR0),LAMP(LC7,LR15),LAMP(LC8,LR0),LAMP(LC8,LR15),LAMP(LC9,LR0),LAMP(LC9,LR15),LAMP(LC10,LR0),LAMP(LC10,LR15),LAMP(LC11,LR0),LAMP(LC11,LR15),LAMP(LC12,LR0),LAMP(LC12,LR15),LAMP(LC13,LR0),LAMP(LC13,LR15),LAMP(LC14,LR0),LAMP(LC14,LR15),LAMP(LC15,LR0),LAMP(LC15,LR1),LAMP(LC15,LR2),LAMP(LC15,LR3),LAMP(LC15,LR4),LAMP(LC15,LR5),LAMP(LC15,LR6),LAMP(LC15,LR7),LAMP(LC15,LR8),LAMP(LC15,LR9),LAMP(LC15,LR10),LAMP(LC15,LR11),LAMP(LC15,LR12),LAMP(LC15,LR13),LAMP(LC15,LR14),LAMP(LC15,LR15),EOF_LAMPS};

static const	LAMP*const sqrlst[]=
{
	lamp_sqr1,
	lamp_sqr2,
	lamp_sqr3,
	lamp_sqr4,
	lamp_sqr5,
	lamp_sqr6,
	lamp_sqr7,
	lamp_sqr8,
	0
};

static 	const 	LAMP	lamp_line1[] = {LAMP(LC0,LR0), EOF_LAMPS};
static 	const 	LAMP	lamp_line2[] = {LAMP(LC1,LR0), LAMP(LC0,LR1),EOF_LAMPS};
static 	const 	LAMP	lamp_line3[] = {LAMP(LC2,LR0), LAMP(LC1,LR1), LAMP(LC0,LR2),EOF_LAMPS};
static 	const 	LAMP	lamp_line4[] = {LAMP(LC3,LR0), LAMP(LC2,LR1), LAMP(LC1,LR2),LAMP(LC0,LR3),EOF_LAMPS};
static 	const 	LAMP	lamp_line5[] = {LAMP(LC4,LR0), LAMP(LC3,LR1), LAMP(LC2,LR2),LAMP(LC1,LR3),LAMP(LC0,LR4),EOF_LAMPS};
static 	const 	LAMP	lamp_line6[] = {LAMP(LC5,LR0), LAMP(LC4,LR1), LAMP(LC3,LR2),LAMP(LC2,LR3),LAMP(LC1,LR4),LAMP(LC0,LR5),EOF_LAMPS};
static 	const 	LAMP	lamp_line7[] = {LAMP(LC6,LR0), LAMP(LC5,LR1), LAMP(LC4,LR2),LAMP(LC3,LR3),LAMP(LC2,LR4),LAMP(LC1,LR5),LAMP(LC0,LR6),EOF_LAMPS};
static 	const 	LAMP	lamp_line8[] = {LAMP(LC7,LR0), LAMP(LC6,LR1), LAMP(LC5,LR2),LAMP(LC4,LR3),LAMP(LC3,LR4),LAMP(LC2,LR5),LAMP(LC1,LR6),LAMP(LC0,LR7),EOF_LAMPS};
static 	const 	LAMP	lamp_line9[] = {LAMP(LC8,LR0), LAMP(LC7,LR1), LAMP(LC6,LR2),LAMP(LC5,LR3),LAMP(LC4,LR4),LAMP(LC3,LR5),LAMP(LC2,LR6),LAMP(LC1,LR7),LAMP(LC0,LR8),EOF_LAMPS};
static 	const 	LAMP	lamp_line10[] = {LAMP(LC9,LR0), LAMP(LC8,LR1), LAMP(LC7,LR2),LAMP(LC6,LR3),LAMP(LC5,LR4),LAMP(LC4,LR5),LAMP(LC3,LR6),LAMP(LC2,LR7),LAMP(LC1,LR8),LAMP(LC0,LR9),EOF_LAMPS};
static 	const 	LAMP	lamp_line11[] = {LAMP(LC10,LR0), LAMP(LC9,LR1), LAMP(LC8,LR2),LAMP(LC7,LR3),LAMP(LC6,LR4),LAMP(LC5,LR5),LAMP(LC4,LR6),LAMP(LC3,LR7),LAMP(LC2,LR8),LAMP(LC1,LR9),LAMP(LC0,LR10),EOF_LAMPS};
static 	const 	LAMP	lamp_line12[] = {LAMP(LC11,LR0), LAMP(LC10,LR1), LAMP(LC9,LR2),LAMP(LC8,LR3),LAMP(LC7,LR4),LAMP(LC6,LR5),LAMP(LC5,LR6),LAMP(LC4,LR7),LAMP(LC3,LR8),LAMP(LC2,LR9),LAMP(LC1,LR10),LAMP(LC0,LR11),EOF_LAMPS};
static 	const 	LAMP	lamp_line13[] = {LAMP(LC12,LR0), LAMP(LC11,LR1), LAMP(LC10,LR2),LAMP(LC9,LR3),LAMP(LC8,LR4),LAMP(LC7,LR5),LAMP(LC6,LR6),LAMP(LC5,LR7),LAMP(LC4,LR8),LAMP(LC3,LR9),LAMP(LC2,LR10),LAMP(LC1,LR11),LAMP(LC0,LR12),EOF_LAMPS};
static 	const 	LAMP	lamp_line14[] = {LAMP(LC13,LR0), LAMP(LC12,LR1), LAMP(LC11,LR2),LAMP(LC10,LR3),LAMP(LC9,LR4),LAMP(LC8,LR5),LAMP(LC7,LR6),LAMP(LC6,LR7),LAMP(LC5,LR8),LAMP(LC4,LR9),LAMP(LC3,LR10),LAMP(LC2,LR11),LAMP(LC1,LR12),LAMP(LC0,LR13),EOF_LAMPS};
static 	const 	LAMP	lamp_line15[] = {LAMP(LC14,LR0), LAMP(LC13,LR1), LAMP(LC12,LR2),LAMP(LC11,LR3),LAMP(LC10,LR4),LAMP(LC9,LR5),LAMP(LC8,LR6),LAMP(LC7,LR7),LAMP(LC6,LR8),LAMP(LC5,LR9),LAMP(LC4,LR10),LAMP(LC3,LR11),LAMP(LC2,LR12),LAMP(LC1,LR13),LAMP(LC0,LR14),EOF_LAMPS};
static 	const 	LAMP	lamp_line16[] = {LAMP(LC15,LR0), LAMP(LC14,LR1), LAMP(LC13,LR2),LAMP(LC12,LR3),LAMP(LC11,LR4),LAMP(LC10,LR5),LAMP(LC9,LR6),LAMP(LC8,LR7),LAMP(LC7,LR8),LAMP(LC6,LR9),LAMP(LC5,LR10),LAMP(LC4,LR11),LAMP(LC3,LR12),LAMP(LC2,LR13),LAMP(LC1,LR14),LAMP(LC0,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line17[] = {LAMP(LC15,LR1), LAMP(LC14,LR2), LAMP(LC13,LR3),LAMP(LC12,LR4),LAMP(LC11,LR5),LAMP(LC10,LR6),LAMP(LC9,LR7),LAMP(LC8,LR8),LAMP(LC7,LR9),LAMP(LC6,LR10),LAMP(LC5,LR11),LAMP(LC4,LR12),LAMP(LC3,LR13),LAMP(LC2,LR14),LAMP(LC1,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line18[] = {LAMP(LC15,LR2), LAMP(LC14,LR3), LAMP(LC13,LR4),LAMP(LC12,LR5),LAMP(LC11,LR6),LAMP(LC10,LR7),LAMP(LC9,LR8),LAMP(LC8,LR9),LAMP(LC7,LR10),LAMP(LC6,LR11),LAMP(LC5,LR12),LAMP(LC4,LR13),LAMP(LC3,LR14),LAMP(LC2,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line19[] = {LAMP(LC15,LR3), LAMP(LC14,LR4), LAMP(LC13,LR5),LAMP(LC12,LR6),LAMP(LC11,LR7),LAMP(LC10,LR8),LAMP(LC9,LR9),LAMP(LC8,LR10),LAMP(LC7,LR11),LAMP(LC6,LR12),LAMP(LC5,LR13),LAMP(LC4,LR14),LAMP(LC3,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line20[] = {LAMP(LC15,LR4), LAMP(LC14,LR5), LAMP(LC13,LR6),LAMP(LC12,LR7),LAMP(LC11,LR8),LAMP(LC10,LR9),LAMP(LC9,LR10),LAMP(LC8,LR11),LAMP(LC7,LR12),LAMP(LC6,LR13),LAMP(LC5,LR14),LAMP(LC4,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line21[] = {LAMP(LC15,LR5), LAMP(LC14,LR6), LAMP(LC13,LR7),LAMP(LC12,LR8),LAMP(LC11,LR9),LAMP(LC10,LR10),LAMP(LC9,LR11),LAMP(LC8,LR12),LAMP(LC7,LR13),LAMP(LC6,LR14),LAMP(LC5,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line22[] = {LAMP(LC15,LR6), LAMP(LC14,LR7), LAMP(LC13,LR8),LAMP(LC12,LR9),LAMP(LC11,LR10),LAMP(LC10,LR11),LAMP(LC9,LR12),LAMP(LC8,LR13),LAMP(LC7,LR14),LAMP(LC6,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line23[] = {LAMP(LC15,LR7), LAMP(LC14,LR8), LAMP(LC13,LR9),LAMP(LC12,LR10),LAMP(LC11,LR11),LAMP(LC10,LR12),LAMP(LC9,LR13),LAMP(LC8,LR14),LAMP(LC7,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line24[] = {LAMP(LC15,LR8), LAMP(LC14,LR9), LAMP(LC13,LR10),LAMP(LC12,LR11),LAMP(LC11,LR12),LAMP(LC10,LR13),LAMP(LC9,LR14),LAMP(LC8,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line25[] = {LAMP(LC15,LR9), LAMP(LC14,LR10), LAMP(LC13,LR11),LAMP(LC12,LR12),LAMP(LC11,LR13),LAMP(LC10,LR14),LAMP(LC9,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line26[] = {LAMP(LC15,LR10), LAMP(LC14,LR11), LAMP(LC13,LR12),LAMP(LC12,LR13),LAMP(LC11,LR14),LAMP(LC10,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line27[] = {LAMP(LC15,LR11), LAMP(LC14,LR12), LAMP(LC13,LR13),LAMP(LC12,LR14),LAMP(LC11,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line28[] = {LAMP(LC15,LR12), LAMP(LC14,LR13), LAMP(LC13,LR14),LAMP(LC12,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line29[] = {LAMP(LC15,LR13), LAMP(LC14,LR14), LAMP(LC13,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line30[] = {LAMP(LC15,LR14), LAMP(LC14,LR15),EOF_LAMPS};
static 	const 	LAMP	lamp_line31[] = {LAMP(LC15,LR15), EOF_LAMPS};

static const	LAMP*const linelst[]=
{
	0,
	lamp_line1,
	lamp_line2,
	lamp_line3,
	lamp_line4,
	lamp_line5,
	lamp_line6,
	lamp_line7,
	lamp_line8,
	lamp_line9,
	lamp_line10,
	lamp_line11,
	lamp_line12,
	lamp_line13,
	lamp_line14,
	lamp_line15,
	lamp_line16,
	lamp_line17,
	lamp_line18,
	lamp_line19,
	lamp_line20,
	lamp_line21,
	lamp_line22,
	lamp_line23,
	lamp_line24,
	lamp_line25,
	lamp_line26,
	lamp_line27,
	lamp_line28,
	lamp_line29,
	lamp_line30,
	lamp_line31,
	0
};

static const	BYTE NibbleTable[]=
{
	'0',
	'1',
	'2',
	'3',
	'4',
	'5',
	'6',
	'7',
	'8',
	'9',
	'a',
	'b',
	'c',
	'd',
	'e',
	'f',
};

/* LEDS MENU */
static const	BYTE*const ledcommands[]=
{
	"MULTIPLEXED LEDS MENU",
	"digit",
	"segment",
	"dim",
	"restore",
	"exit",
	0
};

static const	DIGIT	digit_table0_15[]=
{
	LED0,
	LED1,
	LED2,
	LED3,
	LED4,
	LED5,
	LED6,
	LED7,
	LED8,
	LED9,
	LED10,
	LED11,
	LED12,
	LED13,
	LED14,
	LED15,
	EOF_DIGITS
};

static const	DIGIT	digit_table16_31[]=
{
	LED16,
	LED17,
	LED18,
	LED19,
	LED20,
	LED21,
	LED22,
	LED23,
	LED24,
	LED25,
	LED26,
	LED27,
	LED28,
	LED29,
	LED30,
	LED31,
	EOF_DIGITS
};

/* LED Animation Table 0 */
static const	BYTE ledAnim0Table[] =
{
	LED_SEG1,
	LED_SEG2,
	LED_SEG3,
	LED_SEG4,
	LED_SEG5,
	LED_SEG6,
	LED_SEG7,
	0x00,
};

/* LED Animation Table 1 */
static const	UBYTE ledAnim1Table[] =
{
	/* 0 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,

	/* 1 */
	LED_SEG1,
	LED_SEG2,
	LED_SEG2 | LED_SEG3,
	LED_SEG2 | LED_SEG3| LED_SEG4,
	LED_SEG2 | LED_SEG3| LED_SEG5,
	LED_SEG2 | LED_SEG3| LED_SEG6,
	LED_SEG2 | LED_SEG3| LED_SEG7,
	LED_SEG2 | LED_SEG3,

	/* 2 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG4 | LED_SEG5 | LED_SEG7,

	/* 3 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG7,

	/* 4 */
	LED_SEG1,
	LED_SEG2,
	LED_SEG2 | LED_SEG3,
	LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG2 | LED_SEG3 | LED_SEG5,
	LED_SEG2 | LED_SEG3 | LED_SEG6,
	LED_SEG2 | LED_SEG3 | LED_SEG6 | LED_SEG7,

	/* 5 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG3,
	LED_SEG1 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG6,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG6 | LED_SEG7,

	/* 6 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG3,
	LED_SEG1 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* 7 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG7,
	LED_SEG1 | LED_SEG2 | LED_SEG3,

	/* 8 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* 9 */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG6 | LED_SEG7,

	/* A */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG2 | LED_SEG3,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG5,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* b */
	LED_SEG1,
	LED_SEG2,
	LED_SEG3,
	LED_SEG3 | LED_SEG4,
	LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* C */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG3,
	LED_SEG1 | LED_SEG4,
	LED_SEG1 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6,

	/* d */
	LED_SEG1,
	LED_SEG2,
	LED_SEG2 | LED_SEG3,
	LED_SEG2 | LED_SEG3 | LED_SEG4,
	LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5,
	LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG7,

	/* E */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG3,
	LED_SEG1 | LED_SEG4,
	LED_SEG1 | LED_SEG4 | LED_SEG5,
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* F */
	LED_SEG1,
	LED_SEG1 | LED_SEG2,
	LED_SEG1 | LED_SEG3,
	LED_SEG1 | LED_SEG4,
	LED_SEG1 | LED_SEG5,
	LED_SEG1 | LED_SEG5 | LED_SEG6,
	LED_SEG1 | LED_SEG5 | LED_SEG6 | LED_SEG7,

	/* Finish */
	LED_SEG1,
};

/* LED tabel 0-F */
static const	UBYTE ledHexTable[] =
{
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6,				/* 0 */
	LED_SEG2 | LED_SEG3,															/* 1 */
	LED_SEG1 | LED_SEG2 | LED_SEG4 | LED_SEG5 | LED_SEG7,							/* 2 */
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG7,							/* 3 */
	LED_SEG2 | LED_SEG3 | LED_SEG6 | LED_SEG7,										/* 4 */
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG6 | LED_SEG7,							/* 5 */
	LED_SEG1 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,				/* 6 */
	LED_SEG1 | LED_SEG2 | LED_SEG3,													/* 7 */
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,		/* 8 */
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG6 | LED_SEG7,				/* 9 */
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG5 | LED_SEG6 | LED_SEG7,				/* A */
	LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,							/* b */
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6,										/* C */
	LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG7,							/* d */
	LED_SEG1 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,							/* E */
	LED_SEG1 | LED_SEG5 | LED_SEG6 | LED_SEG7,										/* F */
};

/* clear LED Table */
static const	UBYTE ledWipeTable[] =
{
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG5 | LED_SEG6 | LED_SEG7,
	LED_SEG1 | LED_SEG2 | LED_SEG3 | LED_SEG4 | LED_SEG7,
	LED_SEG2 | LED_SEG3,
	0x00,
};

/* LED character table */
static const	BYTE ledchartable[] =
{
	0xbf,
	0x06,
	0xdb,
	0x4f,
	0xe6,
	0x6d,
	0xfd,
	0x07,
	0xff,
	0x67,
	0xf7,
	0x7c,
	0xb9,
	0x5e,
	0xf9,
	0x71
};

/* LED number table */
static const	BYTE lednumbertable[] =
{
	0x3f,	/* 0 */
	0x06,	/* 1 */
	0x5b,	/* 2 */
	0x4f,	/* 3 */
	0x66,	/* 4 */
	0x6d, 	/* 5 */
	0x7d,	/* 6 */
	0x07,	/* 7 */
	0x7f,	/* 8 */
	0x67,	/* 9 */
	0x80	/* decimal point */
};

/* INPUTS MENU */
static const	BYTE*const inputcommands[]=
{
	"INPUTS",
	"inputs",
	"pushbutton",
	"metersense",
	"exit",
	0
};

/* INPUTS TABLE */
static	const	INPUT	inputtable[]=
{
	IP0,IP1,IP2,IP3,IP4,IP5,IP6,IP7,
	IP8,IP9,IP10,IP11,IP12,IP13,IP14,IP15,
	IP16,IP17,IP18,IP19,IP20,IP21,IP22,IP23,
	IP24,IP25,IP26,IP27,IP28,IP29,IP30,IP31,
	EOF_INPUTS
};

/* OUTPUTS TABLE */
static const OUTPUT outputtable[]=
{
	OP0,OP1,OP2,OP3,OP4,OP5,OP6,OP7,
	OP8,OP9,OP10,OP11,OP12,OP13,OP14,OP15,
	OP16,OP17,OP18,OP19,OP20,OP21,OP22,OP23,
	OP24,OP25,OP26,OP27,OP28,OP29,OP30,OP31,
	OP32,OP33,OP34,OP35,OP36,OP37,OP38,OP39,
	OP40,OP41,OP42,OP43,OP44,OP45,OP46,OP47,
	OP48,OP49,OP50,OP51,OP52,OP53,OP54,OP55,
	OP56,OP57,OP58,OP59,OP60,OP61,OP62,OP63
};

/* OUTPUTS SQUARE */
static const OUTPUT output_sqr_1[]={OP27, OP28, OP35, OP36, EOF_OUTPUTS};
static const OUTPUT output_sqr_2[]={OP18, OP19, OP20, OP21, OP26, OP29, OP34,OP37, OP42, OP43, OP44, OP45, EOF_OUTPUTS};
static const OUTPUT output_sqr_3[]={OP9, OP10, OP11, OP12, OP13, OP14, OP17, OP22, OP25, OP30, OP33, OP38, OP41, OP46, OP49, OP50, OP51, OP52, OP53, OP54,EOF_OUTPUTS};
static const OUTPUT output_sqr_4[]={OP0, OP1, OP2, OP3, OP4, OP5, OP6, OP7, OP8, OP15, OP16, OP23, OP24, OP31, OP32, OP39, OP40, OP47, OP48, OP55, OP56, OP57, OP58, OP59, OP60, OP61, OP62, OP63, EOF_OUTPUTS};

static	const	OUTPUT*const od_outputs[]=
{
	output_sqr_4,
	output_sqr_3,
	output_sqr_2,
	output_sqr_1,
	0
};

/* OUTPUTS DIAGONAL LINES */
static const OUTPUT output_line_1[]={OP7,EOF_OUTPUTS};
static const OUTPUT output_line_2[]={OP6, OP15, EOF_OUTPUTS};
static const OUTPUT output_line_3[]={OP5, OP14, OP23, EOF_OUTPUTS};
static const OUTPUT output_line_4[]={OP4, OP13, OP22, OP31, EOF_OUTPUTS};
static const OUTPUT output_line_5[]={OP3, OP12, OP21, OP30, OP39, EOF_OUTPUTS};
static const OUTPUT output_line_6[]={OP2, OP11, OP20, OP29, OP38, OP47, EOF_OUTPUTS};
static const OUTPUT output_line_7[]={OP1, OP10, OP19, OP28, OP37, OP46, OP55, EOF_OUTPUTS};
static const OUTPUT output_line_8[]={OP0, OP9, OP18, OP27, OP36, OP45, OP54, OP63, EOF_OUTPUTS};
static const OUTPUT output_line_9[]={OP8, OP17, OP26, OP35, OP44, OP53, OP62, EOF_OUTPUTS};
static const OUTPUT output_line_10[]={OP16, OP25, OP34, OP43, OP52, OP61, EOF_OUTPUTS};
static const OUTPUT output_line_11[]={OP24, OP33, OP42, OP51, OP60, EOF_OUTPUTS};
static const OUTPUT output_line_12[]={OP32, OP41, OP50, OP59, EOF_OUTPUTS};
static const OUTPUT output_line_13[]={OP40, OP49, OP58, EOF_OUTPUTS};
static const OUTPUT output_line_14[]={OP48, OP57, EOF_OUTPUTS};
static const OUTPUT output_line_15[]={OP56, EOF_OUTPUTS};

static	const	OUTPUT*const od_lines[]=
{
	output_line_1,
	output_line_2,
	output_line_3,
	output_line_4,
	output_line_5,
	output_line_6,
	output_line_7,
	output_line_8,
	output_line_9,
	output_line_10,
	output_line_11,
	output_line_12,
	output_line_13,
	output_line_14,
	output_line_15,
	0
};

/* REEL MENUS */
static	const	BYTE*const reelcommands[]=
{
	"REEL MENU",
	"init",
	"step1",
	"step2",
	"step3",
	"step4",
	"spin",
	"skill",
	"status",
	"exit",
	0
};

/* SERIAL MENUS */
/* Top level menu */
static	const	BYTE*const uartcommands[]=
{
	"UARTS MENU",
	"cfuart1",
	"fpuart0",
	"fpuart1",
	"duart0",
	"duart1",
	"exit",
	0
};

/* Coldfire Serial Module */
typedef	enum
{
	CFCONFIG1CMD,
	CFROUTE1CMD,
	CFTRANS1CMD,
	CFREC1CMD,
	CFEXITUART1CMD,
} CFUART1TESTCMD;

static	const	BYTE*const cfuart1commands[]=
{
	"Coldfire UART 1 MENU",
	"configure",
	"route",
	"transmit",
	"receive",
	"exit",
	0
};

/* FPGA UART 0 */
typedef	enum
{
	FPGACONFIG0CMD,
	FPGAROUTE0CMD,
	FPGATRANS0CMD,
	FPGAREC0CMD,
	FPGAEXITUART0CMD,
} FPGAUART0TESTCMD;

static	const	BYTE*const fpgauart0commands[]=
{
	"FPGA UART 0 MENU",
	"configure",
	"route",
	"transmit",
	"receive",
	"exit",
	0
};

/* FPGA UART 1 */
typedef	enum
{
	FPGACONFIG1CMD,
	FPGAROUTE1CMD,
	FPGATRANS1CMD,
	FPGAREC1CMD,
	FPGAEXITUART1CMD,
} FPGAUART1TESTCMD;

static	const	BYTE*const fpgauart1commands[]=
{
	"FPGA UART 1 MENU",
	"configure",
	"route",
	"transmit",
	"receive",
	"exit",
	0
};

/* DUART channel 0 */
typedef	enum
{
	DUARTCONFIG0CMD,
	DUARTROUTE0CMD,
	DUARTTRANS0CMD,
	DUARTREC0CMD,
	EXITDUART0CMD,
} DUART0TESTCMD;

static	const	BYTE*const duart0commands[]=
{
	"DUART CHANNEL 0 MENU",
	"configure",
	"route",
	"transmit",
	"receive",
	"exit",
	0
};

/* DUART channel 1 */
typedef	enum
{
	DUARTCONFIG1CMD,
	DUARTROUTE1CMD,
	DUARTTRANS1CMD,
	DUARTREC1CMD,
	EXITDUART1CMD,
} DUART1TESTCMD;

static const	BYTE*const duart1commands[]=
{
	"DUART CHANNEL 1 MENU",
	"configure",
	"route",
	"transmit",
	"receive",
	"exit",
	0
};

/* supported baud rates */
static	const	BYTE*const baudrates[]=
{
	"19200",
	"9600",
	"4800",
	"2400",
	"1200",
	0
};

/* parity settings */
static	const	BYTE*const parity[]=
{
	"none",
	"odd",
	"even",
	0
};

/* number of data bits */
static	const	BYTE*const databits[]=
{
	"7",
	"8",
	0
};

/* number of stop bits */
static	const	BYTE*const stopbits[]=
{
	"1",
	"2",
	0
};

/* available routes */
static	const	BYTE*const routes[]=
{
	"bacta",
	"rs232a",
	"rs232c",
	"rs232d",
	"cctalk1",
	"cctalk2",
	"ttl",
	"rs485",
	0
};

/* AUDIO MAIN MENU */
static const	BYTE*const audiocommands[] =
{
	"HSF AUDIO MENU",
	"dir",
	"setvol",
	"play",
	"loop",
	"quiet",
	"exit",
	0
};

/* VOLUME MENU */
static const	BYTE*const volumecommands[] =
{
	"left",
	"right",
	"both",
	0
};


/* CHANNELS MENU */
static const	BYTE*const channelcommands[] =
{
	"left0",
	"right0",
	"stereo0",
	"left1",
	"right1",
	"stereo1",
	0
};

/* CSD MENU */
static	const	BYTE*const csdcommands[]=
{
	"PIC MENU",
	"readrtc",
	"readrtcfine",
	"setrtc",
	"readlog",
	"clearlog",
	"percent",
	"stake",
	"dil1",
	"dil2",
	"revision",
	"exit",
	0
};

/* E2ROM MENU */
static const	BYTE*const e2romcommands[]=
{
	"E2PROM MENU",
	"read",
	"write",
	"exit",
	0
};

/****	Type Definitions */

/****	Prototypes */
#include	"demo.p"

/********************************************************************/
