/*-------------------------------------------------------------------
Name......... devices.c
Author....... Marc Adams
Date......... 15/09/03
Description.. The system device list, all devices attached to the
............. system have thier drivers loaded in the order they
............. appear in this list.
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

/****	Include Files */

#include	"hardware.h"
#include	"peripherals.h"
#include	"interface.h"
#include	"devices.p"

/****	Local Definitions */
/****	Global Variables */
/****	Local Variables */
/****	Global Constants */
/****	Device Install List

This list defines the device drivers which will be installed on startup.
The first field points to a device,which may be installed dependant on
the value (TRUE/FALSE) returned by the device selector function (second
field). Where devices have multiple configuration options the
configuration used is dependant on the index returned by the configuration
selector function (third field) A zero in place of a device selector
function means always install the device. A zero in place of the
configuration selector means that the configuration list contains only
one entry and that configuration is to be used.

*/

const	INSTALLDEVICE	DeviceList[]=
{
//	{&ATADevice			,0	,0,0},
	{&DUART0Device		,0	,0,0},
	{&SerialDevice		,0	,0,0},
	{&LampDevice		,0	,0,0},
	{&OutputDevice		,0	,0,0},
	{&StepperDevice		,0	,0,0},
	{&MXIDevice			,0	,0,0},
	{&FPUART0Device		,0	,0,0},
	{&FPUART1Device		,0	,0,0},
	{&TimerDevice		,0	,0,0},
	{&MbusDevice		,0	,0,0},
	{&PICDevice			,0	,0,0},
	{&E2RomDevice		,0	,0,0},
//	{&Calypso32Device	,0	,0,0},
	{&AudioHSFDevice	,0	,0,0},
	{0,0,0}
};


/****	Constant Device Type Lists
These lists are used by higher level logical drivers to make a number of physical
devices of the same type appear as a single device
E.G. Two DUARTS with separate drivers will look like a single device with four
ports (Device lists with one entry are just for completeness)
*/

const	DEVICE*const	LampDevices[]={&LampDevice,0};
const	DEVICE*const	InputDevices[]={&MXIDevice,0};
const	DEVICE*const	OutputDevices[]={&OutputDevice,0};
const	DEVICE*const	SerialDevices[]={&SerialDevice,0};
const	DEVICE*const	SteppersDevices[]={&StepperDevice,0};

/****	Variable Device Type Lists
These are built at runtime for device types where the devices are autodetected or
may vary depending on option switch settings
*/

/****	Device Type Build List
This list defines which device type lists are to be built at runtime and which
device type they are associated with
*/

const	BUILDTYPE		DeviceTypeBuildList[]=
{
	{0,0}
};

/****	Local Constants */
/****	Option Lists
These are used to determine which configuration is used
*/

/************************************************************************
*****	Functions
*************************************************************************/

/************************************************************************/
